@@ -1,5 +1,4 @@
 # Copyright (c) Open-MMLab. All rights reserved.
-import json
 import os.path as osp
 import shutil
 import sys
@@ -9,6 +8,7 @@ from collections import abc
 from importlib import import_module
 
 from addict import Dict
+from yapf.yapflib.yapf_api import FormatCode
 
 from .path import check_file_exist
 
@@ -151,9 +151,10 @@ class Config(object):
             if isinstance(v, dict) and k in b and not v.pop(DELETE_KEY, False):
                 if not isinstance(b[k], dict):
                     raise TypeError(
-                        f'{k}={v} cannot be inherited from base because {k} '
-                        'is a dict in the child config. You may '
-                        f'set `{DELETE_KEY}=True` to ignore the base config')
+                        f'{k}={v} in child config cannot inherit from base '
+                        f'because {k} is a dict in the child config but is of '
+                        f'type {type(b[k])} in base config. You may set '
+                        f'`{DELETE_KEY}=True` to ignore the base config')
                 b[k] = Config._merge_a_into_b(v, b[k])
             else:
                 b[k] = v
@@ -262,6 +263,12 @@ class Config(object):
 
         cfg_dict = self._cfg_dict.to_dict()
         text = _format_dict(cfg_dict, outest_level=True)
+        # copied from setup.cfg
+        yapf_style = dict(
+            based_on_style='pep8',
+            blank_line_before_nested_class_or_def=True,
+            split_before_expression_after_opening_paren=True)
+        text, _ = FormatCode(text, style_config=yapf_style, verify=True)
 
         return text
 
@@ -290,16 +297,28 @@ class Config(object):
     def __iter__(self):
         return iter(self._cfg_dict)
 
-    def dump(self):
-        cfg_dict = super(Config, self).__getattribute__('_cfg_dict')
-        format_text = json.dumps(cfg_dict, indent=2)
-        return format_text
+    def dump(self, file=None):
+        cfg_dict = super(Config, self).__getattribute__('_cfg_dict').to_dict()
+        if self.filename.endswith('.py'):
+            if file is None:
+                return self.pretty_text
+            else:
+                with open(file, 'w') as f:
+                    f.write(self.pretty_text)
+        else:
+            import mmcv
+            if file is None:
+                file_format = self.filename.split('.')[-1]
+                return mmcv.dump(cfg_dict, file_format=file_format)
+            else:
+                mmcv.dump(cfg_dict, file)
 
     def merge_from_dict(self, options):
-        """ Merge list into cfg_dict
+        """Merge list into cfg_dict
 
         Merge the dict parsed by MultipleKVAction into this cfg.
-        Example,
+
+        Examples:
             >>> options = {'model.backbone.depth': 50,
             ...            'model.backbone.with_cp':True}
             >>> cfg = Config(dict(model=dict(backbone=dict(type='ResNet'))))
